<!--
Thanks for taking the time for reporting an issue!

Before reporting an issue on dd-trace-py, please be sure to provide all
necessary information.

If you're hitting a bug, make sure that you're using the latest version of this
library.
-->

### Summary of problem

### Which version of dd-trace-py are you using?

### Which version of pip are you using?


### Which libraries and their versions are you using?

<details>
  <summary>`pip freeze`</summary>
  <!-- Paste output of pip freeze here -->
</details>

### How can we reproduce your problem?

### What is the result that you get?

### What is the result that you expected?
